==================
 Queue Processing
==================

This package ships with a command line application to send all the
messages stored in a queue directory. It can be invoked periodically
(e.g., via cron) or run as a background process.

.. command-output:: zope-sendmail --help
